@@ -2,7 +2,7 @@ import React from 'react'
 import Selectbox from '../../common/Selectbox'
 import MultiRowTextBoxContainer from '../MultiRowTextBox/MultiRoxTextBoxContainer'
 import { getClassNames } from '../../../helpers/HostedEngineSetupUtil'
-import { amdCpuTypes, intelCpuTypes } from "../constants"
+import {amdCpuTypes, deploymentTypes, intelCpuTypes, messages} from "../constants"
 
 const consoleTypes = [
     { key: "vnc", title: "VNC" },
@@ -25,26 +25,38 @@ const rootSshAccessOptions = [
     { key: "without-password", title: "Without Password" }
 ];
 
-const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs, handleDnsAddressUpdate,
-                    handleDnsAddressDelete, handleImportApplianceUpdate, handleVmConfigUpdate, heSetupModel,
-                    importAppliance, showApplPath, verifyDns, verifyReverseDns, warningMsgs }) => {
+const HeWizardVm = ({appliances, applPathSelection, cpuArch, deploymentType, errorMsg, errorMsgs,
+                    handleDnsAddressUpdate, handleDnsAddressDelete, handleImportApplianceUpdate, handleVmConfigUpdate,
+                    heSetupModel, importAppliance, showApplPath, verifyDns, verifyReverseDns, warningMsgs}) => {
     const vmConfig = heSetupModel.vm;
     const vdsmConfig = heSetupModel.vdsm;
     const storageConfig = heSetupModel.storage;
     const networkConfig = heSetupModel.network;
 
+    const maxAvailMem = vmConfig.vmMemSizeMB.range.max.toLocaleString();
+    const memWarningMessage = messages.RECOMMENDED_MIN_MEM_AVAIL_WARNING + ` Currently, only ${maxAvailMem}MB is available.`;
+
     return (
         <div>
             <form className="form-horizontal he-form-container">
                 {errorMsg &&
-                <div className="row" style={{marginLeft: "40px"}}>
-                    <div className="alert alert-danger col-sm-8">
+                <div className="row">
+                    <div className="alert alert-danger col-sm-11">
                         <span className="pficon pficon-error-circle-o" />
                         <strong>{errorMsg}</strong>
                     </div>
                 </div>
                 }
 
+                {vmConfig.vmMemSizeMB.range.max < 4096 &&
+                <div className="row">
+                    <div className="alert alert-warning col-sm-11">
+                        <span className="pficon pficon-warning-triangle-o" />
+                        <strong>{memWarningMessage}</strong>
+                    </div>
+                </div>
+                }
+
                 <div className="form-group">
                     <label className="col-md-3 control-label">Auto-import Appliance</label>
                     <div className="col-md-3">
@@ -81,29 +93,33 @@ const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs
                     </div>
                 </div>
 
-                <div className={getClassNames("cpu", errorMsgs) + " he-cpu-select-row"} >
-                    <label className="col-md-3 control-label">CPU Type</label>
-                    <div className="col-md-4 he-cpu-select-col">
-                        <div className="he-cpu-select-container">
-                            <Selectbox optionList={cpuArch.vendor === "Intel" ? intelCpuTypes : amdCpuTypes}
-                                       selectedOption={heSetupModel.vdsm.cpu.value}
-                                       callBack={(e) => handleVmConfigUpdate("cpu", e, "vdsm")}
-                            />
+                {deploymentType === deploymentTypes.OTOPI_DEPLOYMENT &&
+                    <span>
+                        <div className={getClassNames("cpu", errorMsgs) + " he-cpu-select-row"} >
+                            <label className="col-md-3 control-label">CPU Type</label>
+                            <div className="col-md-4 he-cpu-select-col">
+                                <div className="he-cpu-select-container">
+                                    <Selectbox optionList={cpuArch.vendor === "Intel" ? intelCpuTypes : amdCpuTypes}
+                                               selectedOption={heSetupModel.vdsm.cpu.value}
+                                               callBack={(e) => handleVmConfigUpdate("cpu", e, "vdsm")}
+                                    />
+                                </div>
+                            </div>
+                            <div className="col-md-1 he-cpu-select-warn-col">
+                                {warningMsgs.cpu &&
+                                    <i className="pficon pficon-warning-triangle-o he-warning-icon vertical-center"
+                                       rel="tooltip" title={warningMsgs.cpu}/>
+                                }
+                            </div>
                         </div>
-                    </div>
-                    <div className="col-md-1 he-cpu-select-warn-col">
-                        {warningMsgs.cpu &&
-                            <i className="pficon pficon-warning-triangle-o he-warning-icon vertical-center"
-                               rel="tooltip" title={warningMsgs.cpu}/>
-                        }
-                    </div>
-                </div>
-                <div className={getClassNames("cpu", errorMsgs)}>
-                    <div className="col-md-3" />
-                    <div className="col-md-6">
-                        {errorMsgs.cpu && <span className="help-block">{errorMsgs.cpu}</span>}
-                    </div>
-                </div>
+                        <div className={getClassNames("cpu", errorMsgs)}>
+                            <div className="col-md-3" />
+                            <div className="col-md-6">
+                                {errorMsgs.cpu && <span className="help-block">{errorMsgs.cpu}</span>}
+                            </div>
+                        </div>
+                    </span>
+                }
 
                 <div className={getClassNames("vmVCpus", errorMsgs)}>
                     <label className="col-md-3 control-label">Number of Virtual CPUs</label>
@@ -117,21 +133,7 @@ const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs
                                value={vmConfig.vmVCpus.value}
                                onChange={(e) => handleVmConfigUpdate("vmVCpus", e.target.value, "vm")}
                         />
-                        {errorMsgs.vmVCpus && <span className="he">{errorMsgs.vmVCpus}</span>}
-                    </div>
-                </div>
-
-                <div className={getClassNames("imgSizeGB", errorMsgs)}>
-                    <label className="col-md-3 control-label">Disk Size (GB)</label>
-                    <div className="col-md-6 he-text-with-units">
-                        <input type="number" style={{width: "60px"}}
-                               placeholder="Disk Size"
-                               title="Enter the disk size for the VM."
-                               className="form-control"
-                               value={storageConfig.imgSizeGB.value}
-                               onChange={(e) => handleVmConfigUpdate("imgSizeGB", e.target.value, "storage")}
-                        />
-                        {errorMsgs.imgSizeGB && <span className="help-block">{errorMsgs.imgSizeGB}</span>}
+                        {errorMsgs.vmVCpus && <span className="help-block">{errorMsgs.vmVCpus}</span>}
                     </div>
                 </div>
 
@@ -147,7 +149,7 @@ const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs
                                value={vmConfig.vmMemSizeMB.value}
                                onChange={(e) => handleVmConfigUpdate("vmMemSizeMB", e.target.value, "vm")}
                         />
-                        <span className="info-block">{vmConfig.vmMemSizeMB.range.max.toLocaleString() + " "} MB available</span>
+                        <span className="info-block">{vmConfig.vmMemSizeMB.range.max.toLocaleString()}MB available</span>
                         {errorMsgs.vmMemSizeMB && <span className="help-block">{errorMsgs.vmMemSizeMB}</span>}
                     </div>
                 </div>
@@ -176,6 +178,20 @@ const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs
                     </div>
                 </div>
 
+                <div className={getClassNames("host_name", errorMsgs)}>
+                    <label className="col-md-3 control-label">Host FQDN</label>
+                    <div className="col-md-4">
+                        <input type="text"
+                               placeholder="engine-host.example.com"
+                               title="Enter the host's FQDN."
+                               className="form-control"
+                               value={networkConfig.host_name.value}
+                               onChange={(e) => handleVmConfigUpdate("host_name", e.target.value, "network")}
+                        />
+                        {errorMsgs.host_name && <span className="help-block">{errorMsgs.host_name}</span>}
+                    </div>
+                </div>
+
                 <div className={getClassNames("cloudinitVMTZ", errorMsgs)}>
                     <label className="col-md-3 control-label">Host Time Zone</label>
                     <div className="col-md-3">
@@ -218,34 +234,17 @@ const HeWizardVm = ({appliances, applPathSelection, cpuArch, errorMsg, errorMsgs
                         </div>
                     </div>
 
-                    <div className={getClassNames("cloudinitInstanceHostName", errorMsgs)}>
-                        <label className="col-md-3 control-label">Engine VM Host Name</label>
-                        <div className="col-md-3">
-                            <input type="text" placeholder="Engine VM Host Name"
-                                   className="form-control"
-                                   value={vmConfig.cloudinitInstanceHostName.value}
-                                   onChange={(e) => handleVmConfigUpdate("cloudinitInstanceHostName", e.target.value, "vm")}
-                            />
-                            {errorMsgs.cloudinitInstanceHostName && <span className="help-block">{errorMsgs.cloudinitInstanceHostName}</span>}
-                        </div>
-                    </div>
-
-                    <div className={getClassNames("cloudinitInstanceDomainName", errorMsgs)}>
-                        <label className="col-md-3 control-label he-long-label-name">Engine VM Domain Name</label>
-                        <div className="col-md-3">
-                            <input type="text" placeholder="Engine VM Domain"
-                                   className="form-control"
-                                   value={vmConfig.cloudinitInstanceDomainName.value}
-                                   onChange={(e) => handleVmConfigUpdate("cloudinitInstanceDomainName", e.target.value, "vm")}
-                            />
-                            {errorMsgs.cloudinitInstanceDomainName && <span className="help-block">{errorMsgs.cloudinitInstanceDomainName}</span>}
-                        </div>
-                    </div>
-
                     <div className={getClassNames("fqdn", errorMsgs)}>
                         <label className="col-md-3 control-label">Engine VM FQDN</label>
                         <div className="col-md-4">
-                            <label className="value-label" type="text">{networkConfig.fqdn.value}</label>
+                            <input type="text"
+                                   placeholder="ovirt-engine.example.com"
+                                   title="Enter the engine FQDN."
+                                   className="form-control"
+                                   value={networkConfig.fqdn.value}
+                                   onChange={(e) => handleVmConfigUpdate("fqdn", e.target.value, "network")}
+                                   onBlur={(e) => verifyDns(e.target.value)}
+                            />
                             {errorMsgs.fqdn && <span className="help-block">{errorMsgs.fqdn}</span>}
                         </div>
                     </div>
