@@ -236,8 +236,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_USERNAME",
                     ansiblePhasesUsed: [2, 3],
                     description: "Portal User",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -248,8 +248,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_PASSWORD",
                     ansiblePhasesUsed: [2, 3],
                     description: "Portal Password",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -260,8 +260,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_DISCOVER_USERNAME",
                     ansiblePhasesUsed: [2, 3],
                     description: "Discovery User",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -272,8 +272,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_DISCOVER_PASSWORD",
                     ansiblePhasesUsed: [2, 3],
                     description: "Discovery Password",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -284,8 +284,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_PORTAL_ADDR",
                     ansiblePhasesUsed: [3],
                     description: "Portal IP Address",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -298,8 +298,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_IP_TPGT",
                     ansiblePhasesUsed: [3],
                     description: "iSCSI IP TPGT",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -324,8 +324,8 @@ export class HeSetupModel {
                     ansibleVarName: "ISCSI_TARGET",
                     ansiblePhasesUsed: [2, 3],
                     description: "Target Name",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -336,8 +336,8 @@ export class HeSetupModel {
                     ansibleVarName: "LUN_ID",
                     ansiblePhasesUsed: [2,3],
                     description: "Destination LUN",
-                    value: "None",
-                    type: types.NONE,
+                    value: "",
+                    type: types.STRING,
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
@@ -1108,7 +1108,7 @@ export class AnswerFileGenerator {
                 propNames.forEach(
                     function(propName) {
                         const prop = section[propName];
-                        const value = this.checkValue(propName, prop.value);
+                        const value = this.checkValue(prop);
 
                         if (prop.useInAnswerFile) {
                             configString += this.createLine(sectionName, propName, value, prop.type);
@@ -1119,11 +1119,15 @@ export class AnswerFileGenerator {
         return configString;
     }
 
-    checkValue(propName, value) {
-        let retVal = value;
+    checkValue(prop) {
+        let retVal = prop.value;
 
-        if (propName === "domainType" && value === "nfs") {
-            retVal = value + this.model.storage.nfsVersion.value;
+        if (prop.name === "domainType" && prop.value === "nfs") {
+            retVal = prop.value + this.model.storage.nfsVersion.value;
+        }
+
+        if (prop.type === types.STRING && prop.value === "") {
+            retVal = "None";
         }
 
         return retVal;
@@ -1134,7 +1138,13 @@ export class AnswerFileGenerator {
 
         line += answerFilePrefixes[sectionName.toUpperCase()];
         line += key + "=";
-        line += type + ":";
+
+        if (value === "None") {
+            line += types.NONE + ":";
+        } else {
+            line += type + ":";
+        }
+
         line += value + "\n";
 
         return line;
